SCStreamErrorCode

Enum SCStreamErrorCode 

#[non_exhaustive]
#[repr(i32)]
pub enum SCStreamErrorCode {
Show 23 variants UserDeclined = -3_801, FailedToStart = -3_802, MissingEntitlements = -3_803, FailedApplicationConnectionInvalid = -3_804, FailedApplicationConnectionInterrupted = -3_805, FailedNoMatchingApplicationContext = -3_806, AttemptToStartStreamState = -3_807, AttemptToStopStreamState = -3_808, AttemptToUpdateFilterState = -3_809, AttemptToConfigState = -3_810, InternalError = -3_811, InvalidParameter = -3_812, NoWindowList = -3_813, NoDisplayList = -3_814, NoCaptureSource = -3_815, RemovingStream = -3_816, UserStopped = -3_817, FailedToStartAudioCapture = -3_818, FailedToStopAudioCapture = -3_819, FailedToStartMicrophoneCapture = -3_820, SystemStoppedStream = -3_821, InsufficientStorage = -3_822, NotSupported = -3_823,
}
Error codes from Apple’s SCStreamError.Code

These correspond to the error codes returned by ScreenCaptureKit operations.

Based on Apple’s SCStreamErrorCode from SCError.h.

This enum is #[non_exhaustive]. Apple has historically added new codes in point releases (e.g. -3818..=-3819 in macOS 13.0, -3820..=-3821 in macOS 15.0) and is likely to add more. Downstream match statements must include a wildcard arm.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


UserDeclined = -3_801

The user chose not to authorize capture



FailedToStart = -3_802

The stream failed to start



MissingEntitlements = -3_803

The stream failed due to missing entitlements



FailedApplicationConnectionInvalid = -3_804

Failed during recording - application connection invalid



FailedApplicationConnectionInterrupted = -3_805

Failed during recording - application connection interrupted



FailedNoMatchingApplicationContext = -3_806

Failed during recording - context id does not match application



AttemptToStartStreamState = -3_807

Failed due to attempting to start a stream that’s already in a recording state



AttemptToStopStreamState = -3_808

Failed due to attempting to stop a stream that’s already in a recording state



AttemptToUpdateFilterState = -3_809

Failed due to attempting to update the filter on a stream



AttemptToConfigState = -3_810

Failed due to attempting to update stream config on a stream



InternalError = -3_811

Failed to start due to video/audio capture failure



InvalidParameter = -3_812

Failed due to invalid parameter



NoWindowList = -3_813

Failed due to no window list



NoDisplayList = -3_814

Failed due to no display list



NoCaptureSource = -3_815

Failed due to no display or window list to capture



RemovingStream = -3_816

Failed to remove stream



UserStopped = -3_817

The stream was stopped by the user



FailedToStartAudioCapture = -3_818

The stream failed to start audio (macOS 13.0+)



FailedToStopAudioCapture = -3_819

The stream failed to stop audio (macOS 13.0+)



FailedToStartMicrophoneCapture = -3_820

The stream failed to start microphone (macOS 15.0+)



SystemStoppedStream = -3_821

The stream was stopped by the system (macOS 15.0+)



InsufficientStorage = -3_822



NotSupported = -3_823

Implementations

Source

impl SCStreamErrorCode

pub fn from_raw(code: i32) -> Option<Self>

Create from raw error code value

pub const fn as_raw(self) -> i32

Get the raw error code value